@@ -35,7 +35,7 @@ class RFXmlFormatter(FormatterBase):
         try:
             data = document.sourceText
             encoding = document.properties.get('encoding', "UTF-8") if document.properties else "UTF-8"
-            if document.sourceText and document.boundaries:
+            if document.sourceText and document.boundaries and document.annotations:
                 if data.lower().startswith("<?xml"):
                     decl, data = data.split("?>", maxsplit=1)
                     decl += "?>"
@@ -43,7 +43,7 @@ class RFXmlFormatter(FormatterBase):
                 baseNs = root.nsmap.get(None, None)
                 # Ignore all namespaces
                 for el in root.iter():
-                    if baseNs and el.tag not in [ET.Comment, ET.PI, ET.Entity] and el.tag.startswith(f"{{{baseNs}}}"):
+                    if baseNs and el.tag.startswith(f"{{{baseNs}}}"):
                         _, _, el.tag = el.tag.rpartition('}')
                 doc_annexes = root.find("DOC_ANNEXES")
                 if not doc_annexes:
@@ -64,21 +64,20 @@ class RFXmlFormatter(FormatterBase):
                         node = r[0]
                         boundaries[node] = Range.closedOpen(boundary.start, boundary.end)
                         buckets[Range.closedOpen(boundary.start, boundary.end)] = node
-                if document.annotations:
-                    for a in document.annotations:
-                        annotation = Annotation(**a) if isinstance(a, dict) else a
-                        form = document.text[annotation.start:annotation.end]
-                        if buckets.contains(annotation.start) and buckets.contains(annotation.end):
-                            zones = buckets[Range.closedOpen(annotation.start, annotation.end)]
-                            for zone in zones:
-                                for term in annotation.terms:
-                                    ident = term.identifier if parameters.absolute_uri\
-                                        else term.identifier[term.identifier.index("#") + 1:]
-                                    terms[zone][ident].append(form)
+                for a in document.annotations:
+                    annotation = Annotation(**a) if isinstance(a, dict) else a
+                    form = document.text[annotation.start:annotation.end]
+                    if buckets.contains(annotation.start) and buckets.contains(annotation.end):
+                        zones = buckets[Range.closedOpen(annotation.start, annotation.end)]
+                        for zone in zones:
+                            for term in annotation.terms:
+                                ident = term.identifier if parameters.absolute_uri\
+                                    else term.identifier[term.identifier.index("#") + 1:]
+                                terms[zone][ident].append(form)
 
                 def left_longest_match(item):
                     r: Range = item[1]
-                    return r.lowerEndpoint(), r.lowerEndpoint() - r.upperEndpoint()
+                    return r.lowerEndpoint(), r.upperEndpoint() - r.lowerEndpoint()
 
                 sorted_boundaries = sorted(boundaries.items(), key=left_longest_match, reverse=False)
 
@@ -99,14 +98,12 @@ class RFXmlFormatter(FormatterBase):
                             descripteurs.append(descripteur)
                         thesaurus.append(descripteurs)
 
-                data = ET.tostring(root, pretty_print=True, encoding=encoding, xml_declaration=True)
+                data = ET.tostring(root, pretty_print=True, encoding=encoding)
             filename = "file.xml"
             if document.properties and "fileName" in document.properties:
                 filepath = Path(document.properties['fileName'])
                 filename = f"{filepath.stem}.xml"
-            media_type = "application/xml" if encoding.lower() == "utf-8" \
-                else f"application/xml; charset={encoding.lower()}"
-            resp = Response(content=data, media_type=media_type)
+            resp = Response(content=data, media_type="application/xml")
             resp.headers["Content-Disposition"] = f"attachment; filename={filename}"
             resp.charset = encoding
             return resp
